@@ -15,16 +15,16 @@
 ##############################################################################
 
 import math
+import os
 
 import openslide
 import PIL
+import tifftools
 from pkg_resources import DistributionNotFound, get_distribution
 
-import tifftools
-
 from large_image.cache_util import LruCacheMetaclass, methodcache
-from large_image.constants import SourcePriority, TILE_FORMAT_PIL
-from large_image.exceptions import TileSourceException
+from large_image.constants import TILE_FORMAT_PIL, SourcePriority
+from large_image.exceptions import TileSourceError, TileSourceFileNotFoundError
 from large_image.tilesource import FileTileSource, nearPowerOfTwo
 
 try:
@@ -68,7 +68,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
         'image/x-tiff': SourcePriority.MEDIUM,
     }
 
-    def __init__(self, path, **kwargs):
+    def __init__(self, path, **kwargs):  # noqa
         """
         Initialize the tile class.  See the base class for other available
         parameters.
@@ -77,23 +77,25 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
         """
         super().__init__(path, **kwargs)
 
-        largeImagePath = self._getLargeImagePath()
+        self._largeImagePath = self._getLargeImagePath()
 
         try:
-            self._openslide = openslide.OpenSlide(largeImagePath)
+            self._openslide = openslide.OpenSlide(self._largeImagePath)
         except openslide.lowlevel.OpenSlideUnsupportedFormatError:
-            raise TileSourceException('File cannot be opened via OpenSlide.')
+            if not os.path.isfile(self._largeImagePath):
+                raise TileSourceFileNotFoundError(self._largeImagePath) from None
+            raise TileSourceError('File cannot be opened via OpenSlide.')
         except openslide.lowlevel.OpenSlideError:
-            raise TileSourceException('File will not be opened via OpenSlide.')
+            raise TileSourceError('File will not be opened via OpenSlide.')
         if libtiff_ctypes:
             try:
-                self._tiffinfo = tifftools.read_tiff(largeImagePath)
+                self._tiffinfo = tifftools.read_tiff(self._largeImagePath)
             except Exception:
                 pass
 
-        svsAvailableLevels = self._getAvailableLevels(largeImagePath)
+        svsAvailableLevels = self._getAvailableLevels(self._largeImagePath)
         if not len(svsAvailableLevels):
-            raise TileSourceException('OpenSlide image size is invalid.')
+            raise TileSourceError('OpenSlide image size is invalid.')
         self.sizeX = svsAvailableLevels[0]['width']
         self.sizeY = svsAvailableLevels[0]['height']
         if (self.sizeX != self._openslide.dimensions[0] or
@@ -111,7 +113,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
             math.log(float(self.sizeX) / self.tileWidth),
             math.log(float(self.sizeY) / self.tileHeight)) / math.log(2))) + 1
         if self.levels < 1:
-            raise TileSourceException(
+            raise TileSourceError(
                 'OpenSlide image must have at least one level.')
         self._svslevels = []
         # Precompute which SVS level should be used for our tile levels.  SVS
@@ -138,19 +140,18 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
                 scale = int(round(svsAvailableLevels[svslevel]['width'] / levelW))
             # If there are no tiles at a particular level, we have to read a
             # larger area of a higher resolution level.  If such an area would
-            # be excessively large, we could have memroy issues, so raise an
+            # be excessively large, we could have memory issues, so raise an
             # error.
             if (self.tileWidth * scale > maxSize or
                     self.tileHeight * scale > maxSize):
                 msg = ('OpenSlide has no small-scale tiles (level %d is at %d '
                        'scale)' % (level, scale))
                 self.logger.info(msg)
-                raise TileSourceException(msg)
+                raise TileSourceError(msg)
             self._svslevels.append({
                 'svslevel': bestlevel,
                 'scale': scale
             })
-        self._largeImagePath = largeImagePath
 
     def _getTileSize(self):
         """
@@ -273,7 +274,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
         svslevel = self._svslevels[z]
         # When we read a region from the SVS, we have to ask for it in the
         # SVS level 0 coordinate system.  Our x and y is in tile space at the
-        # specifed z level, so the offset in SVS level 0 coordinates has to be
+        # specified z level, so the offset in SVS level 0 coordinates has to be
         # scaled by the tile size and by the z level.
         scale = 2 ** (self.levels - 1 - z)
         offsetx = x * self.tileWidth * scale
@@ -287,7 +288,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
                 (self.tileWidth * svslevel['scale'],
                  self.tileHeight * svslevel['scale']))
         except openslide.lowlevel.OpenSlideError as exc:
-            raise TileSourceException(
+            raise TileSourceError(
                 'Failed to get OpenSlide region (%r).' % exc)
         # Always scale to the svs level 0 tile size.
         if svslevel['scale'] != 1:
@@ -361,6 +362,8 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
             try:
                 return self._openslide.associated_images[imageKey]
             except openslide.lowlevel.OpenSlideError:
+                # Reopen handle after a lowlevel error
+                self._openslide = openslide.OpenSlide(self._largeImagePath)
                 return None
         bytePath = self._largeImagePath
         if not isinstance(bytePath, bytes):
